@@ -2,7 +2,7 @@
 ## R source file
 ## This file is part of rgl
 ##
-## $Id: zzz.R 715 2008-12-10 11:54:24Z murdoch $
+## $Id: zzz.R 762 2009-06-22 13:34:33Z murdoch $
 ##
 
 ##
@@ -59,7 +59,7 @@
   	  rename <- names(entries) != ""
   	  names[rename] <- names(entries)[rename]
       }
-      for (i in seq(along=entries)) 
+      for (i in seq_along(entries)) 
       	  assign(names[i], getNativeSymbolInfo(entries[i], PACKAGE = dll),
       	         envir = environment(.onLoad))
   }
